@@ -1,5 +1,5 @@
 // nullmailer -- a simple relay-only MTA
-// Copyright (C) 1999-2003  Bruce Guenter <bruce@untroubled.org>
+// Copyright (C) 2007  Bruce Guenter <bruce@untroubled.org>
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@ void canonicalize(mystring& domain)
 {
   if(!domain)
     domain = defaulthost;
-  if(domain.find_first('.') < 0) {
+  if(domain != "localhost" && domain.find_first('.') < 0) {
     if(!!defaultdomain) {
       if (!!domain) domain += ".";
       domain += defaultdomain;
