@@ -1,5 +1,5 @@
 // nullmailer -- a simple relay-only MTA
-// Copyright (C) 1999-2003  Bruce Guenter <bruce@untroubled.org>
+// Copyright (C) 2007  Bruce Guenter <bruce@untroubled.org>
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -58,10 +58,8 @@ mystring make_date()
   return mystringjoin(buf) + tz;
 }
 
-extern mystring idhost;
-
 // Message ID strings have the form SECONDS.USEC.PID.nullmailer@HOST
-mystring make_messageid()
+mystring make_messageid(const mystring& idhost)
 {
   struct timeval tv;
   gettimeofday(&tv, 0);
